package com.op.wms.service;

import java.util.List;
import com.op.wms.domain.BaseProduct;

/**
 * 物料信息Service接口
 * 
 * @author Open Platform
 * @date 2023-07-18
 */
public interface IBaseProductService {
	/**
	 * 查询物料信息
	 * 
	 * @param productId 物料信息主键
	 * @return 物料信息
	 */
	public BaseProduct selectBaseProductByProductId(String productId);

	/**
	 * 查询物料信息列表
	 * 
	 * @param baseProduct 物料信息
	 * @return 物料信息集合
	 */
	public List<BaseProduct> selectBaseProductList(BaseProduct baseProduct);

	/**
	 * 新增物料信息
	 * 
	 * @param baseProduct 物料信息
	 * @return 结果
	 */
	public int insertBaseProduct(BaseProduct baseProduct);

	/**
	 * 修改物料信息
	 * 
	 * @param baseProduct 物料信息
	 * @return 结果
	 */
	public int updateBaseProduct(BaseProduct baseProduct);

	/**
	 * 批量删除物料信息
	 * 
	 * @param productIds 需要删除的物料信息主键集合
	 * @return 结果
	 */
	public int deleteBaseProductByProductIds(String[] productIds);

	/**
	 * 删除物料信息信息
	 * 
	 * @param productId 物料信息主键
	 * @return 结果
	 */
	public int deleteBaseProductByProductId(String productId);
}
